@@ -114,25 +114,25 @@ Command::Command(QAbstractItemView *v, Private *pp)
 }
 
 Command::Command(const Key &key)
-    : QObject(0), d(new Private(this, 0))
+    : QObject(nullptr), d(new Private(this, nullptr))
 {
     d->keys_ = std::vector<Key>(1, key);
 }
 
 Command::Command(const std::vector<Key> &keys)
-    : QObject(0), d(new Private(this, 0))
+    : QObject(nullptr), d(new Private(this, nullptr))
 {
     d->keys_ = keys;
 }
 
 Command::Command(const Key &key, Private *pp)
-    : QObject(0), d(pp)
+    : QObject(nullptr), d(pp)
 {
     d->keys_ = std::vector<Key>(1, key);
 }
 
 Command::Command(const std::vector<Key> &keys, Private *pp)
-    : QObject(0), d(pp)
+    : QObject(nullptr), d(pp)
 {
     d->keys_ = keys;
 }
@@ -232,7 +232,7 @@ void Command::cancel()
 
 void Command::addTemporaryView(const QString &title, AbstractKeyListSortFilterProxyModel *proxy, const QString &tabToolTip)
 {
-    if (TabWidget *const tw = d->controller_ ? d->controller_->tabWidget() : 0)
+    if (TabWidget *const tw = d->controller_ ? d->controller_->tabWidget() : nullptr)
         if (QAbstractItemView *const v = tw->addTemporaryView(title, proxy, tabToolTip)) {
             setView(v);
         }
@@ -258,7 +258,7 @@ QVector <Command *> Command::commandsForFiles(const QStringList &files)
 {
     QStringList importFiles, decryptFiles, encryptFiles, checksumFiles;
     QVector <Command *> cmds;
-    Q_FOREACH (const QString &fileName, files) {
+    for (const QString &fileName : files) {
         const unsigned int classification = classify(fileName);
 
         if (classification & Class::AnyCertStoreType) {
@@ -277,16 +277,16 @@ QVector <Command *> Command::commandsForFiles(const QStringList &files)
         }
     }
     if (!importFiles.isEmpty()) {
-        cmds << new ImportCertificateFromFileCommand(importFiles, Q_NULLPTR);
+        cmds << new ImportCertificateFromFileCommand(importFiles, nullptr);
     }
     if (!decryptFiles.isEmpty()) {
-        cmds << new DecryptVerifyFilesCommand(decryptFiles, Q_NULLPTR);
+        cmds << new DecryptVerifyFilesCommand(decryptFiles, nullptr);
     }
     if (!encryptFiles.isEmpty()) {
-        cmds << new SignEncryptFilesCommand(encryptFiles, Q_NULLPTR);
+        cmds << new SignEncryptFilesCommand(encryptFiles, nullptr);
     }
     if (!checksumFiles.isEmpty()) {
-        cmds << new ChecksumVerifyFilesCommand(checksumFiles, Q_NULLPTR);
+        cmds << new ChecksumVerifyFilesCommand(checksumFiles, nullptr);
     }
     return cmds;
 }
@@ -296,8 +296,8 @@ Command *Command::commandForQuery(const QString &query)
 {
     const GpgME::Key &key = Kleo::KeyCache::instance()->findByKeyIDOrFingerprint(query.toLocal8Bit().data());
     if (key.isNull()) {
-        return new LookupCertificatesCommand(query, 0);
+        return new LookupCertificatesCommand(query, nullptr);
     } else {
-        return new DetailsCommand(key, 0);
+        return new DetailsCommand(key, nullptr);
     }
 }
