@@ -164,7 +164,7 @@ static std::vector<Mailbox> extractMailboxes(const Key &key)
 static std::vector<Mailbox> extractMailboxes(const std::vector<Key> &signers)
 {
     std::vector<Mailbox> res;
-    Q_FOREACH (const Key &i, signers) {
+    for (const Key &i : signers) {
         const std::vector<Mailbox> bxs = extractMailboxes(i);
         res.insert(res.end(), bxs.begin(), bxs.end());
     }
@@ -211,8 +211,10 @@ static QString signatureSummaryToString(int summary)
         return i18n("No public certificate to verify the signature");
     } else if (summary & Signature::SigExpired) {
         return i18n("Signature expired");
+#if 0 //Duplicate entry
     } else if (summary & Signature::KeyMissing) {
         return i18n("Certificate missing");
+#endif
     } else if (summary & Signature::CrlMissing) {
         return i18n("CRL missing");
     } else if (summary & Signature::CrlTooOld) {
@@ -518,7 +520,7 @@ static QString formatVerificationResultDetails(const VerificationResult &res, co
     const std::vector<Signature> sigs = res.signatures();
     const std::vector<Key> signers = KeyCache::instance()->findSigners(res);
     QString details;
-    Q_FOREACH (const Signature &sig, sigs) {
+    for (const Signature &sig : sigs) {
         details += formatSignature(sig, DecryptVerifyResult::keyForSignature(sig, signers), info) + QLatin1Char('\n');
     }
     details = details.trimmed();
@@ -880,7 +882,7 @@ class DecryptVerifyTask::Private
 {
     DecryptVerifyTask *const q;
 public:
-    explicit Private(DecryptVerifyTask *qq) : q(qq), m_backend(0), m_protocol(UnknownProtocol)  {}
+    explicit Private(DecryptVerifyTask *qq) : q(qq), m_backend(nullptr), m_protocol(UnknownProtocol)  {}
 
     void slotResult(const DecryptionResult &, const VerificationResult &, const QByteArray &);
 
@@ -1033,7 +1035,7 @@ class DecryptTask::Private
 {
     DecryptTask *const q;
 public:
-    explicit Private(DecryptTask *qq) : q(qq), m_backend(0), m_protocol(UnknownProtocol)  {}
+    explicit Private(DecryptTask *qq) : q(qq), m_backend(nullptr), m_protocol(UnknownProtocol)  {}
 
     void slotResult(const DecryptionResult &, const QByteArray &);
 
@@ -1188,7 +1190,7 @@ class VerifyOpaqueTask::Private
 {
     VerifyOpaqueTask *const q;
 public:
-    explicit Private(VerifyOpaqueTask *qq) : q(qq), m_backend(0), m_protocol(UnknownProtocol)  {}
+    explicit Private(VerifyOpaqueTask *qq) : q(qq), m_backend(nullptr), m_protocol(UnknownProtocol)  {}
 
     void slotResult(const VerificationResult &, const QByteArray &);
 
@@ -1342,7 +1344,7 @@ class VerifyDetachedTask::Private
 {
     VerifyDetachedTask *const q;
 public:
-    explicit Private(VerifyDetachedTask *qq) : q(qq), m_backend(0), m_protocol(UnknownProtocol) {}
+    explicit Private(VerifyDetachedTask *qq) : q(qq), m_backend(nullptr), m_protocol(UnknownProtocol) {}
 
     void slotResult(const VerificationResult &);
 
