@@ -32,6 +32,8 @@
 
 #include <config-kleopatra.h>
 
+#include "kleopatra_debug.h"
+
 #include "task.h"
 #include "task_p.h"
 
@@ -49,11 +51,8 @@
 
 #include <QString>
 
-#include <boost/bind.hpp>
-
 using namespace Kleo;
 using namespace Kleo::Crypto;
-using namespace boost;
 using namespace GpgME;
 
 namespace
@@ -104,7 +103,8 @@ public:
 
 private:
     QString m_progressLabel;
-    double m_processedPercent;
+    int m_progress;
+    int m_totalProgress;
     bool m_asciiArmor;
     int m_id;
 };
@@ -115,7 +115,7 @@ static int nextTaskId = 0;
 }
 
 Task::Private::Private(Task *qq)
-    : q(qq), m_progressLabel(), m_processedPercent(0.0), m_asciiArmor(false), m_id(nextTaskId++)
+    : q(qq), m_progressLabel(), m_progress(0), m_totalProgress(0), m_asciiArmor(false), m_id(nextTaskId++)
 {
 
 }
@@ -138,9 +138,9 @@ bool Task::asciiArmor() const
     return d->m_asciiArmor;
 }
 
-shared_ptr<Task> Task::makeErrorTask(int code, const QString &details, const QString &label)
+std::shared_ptr<Task> Task::makeErrorTask(int code, const QString &details, const QString &label)
 {
-    const shared_ptr<SimpleTask> t(new SimpleTask(label));
+    const std::shared_ptr<SimpleTask> t(new SimpleTask(label));
     t->setResult(t->makeErrorResult(code, details));
     return t;
 }
@@ -150,14 +150,14 @@ int Task::id() const
     return d->m_id;
 }
 
-unsigned long long Task::processedSize() const
+int Task::currentProgress() const
 {
-    return qRound(d->m_processedPercent * totalSize());
+    return d->m_progress;
 }
 
-unsigned long long Task::totalSize() const
+int Task::totalProgress() const
 {
-    return inputSize();
+    return d->m_totalProgress;
 }
 
 QString Task::tag() const
@@ -172,10 +172,10 @@ QString Task::progressLabel() const
 
 void Task::setProgress(const QString &label, int processed, int total)
 {
-    const double percent = total > 0 ? static_cast<double>(processed) / total : 0.0;
-    d->m_processedPercent = percent;
+    d->m_progress = processed;
+    d->m_totalProgress = total;
     d->m_progressLabel = label;
-    Q_EMIT progress(label, processedSize(), totalSize());
+    Q_EMIT progress(label, processed, total, QPrivateSignal());
 }
 
 void Task::start()
@@ -191,7 +191,7 @@ void Task::start()
     } catch (...) {
         QMetaObject::invokeMethod(this, "emitError", Qt::QueuedConnection, Q_ARG(int, makeGnuPGError(GPG_ERR_UNEXPECTED)), Q_ARG(QString, i18n("Unknown exception in Task::start()")));
     }
-    Q_EMIT started();
+    Q_EMIT started(QPrivateSignal());
 }
 
 void Task::emitError(int errCode, const QString &details)
@@ -199,16 +199,16 @@ void Task::emitError(int errCode, const QString &details)
     emitResult(makeErrorResult(errCode, details));
 }
 
-void Task::emitResult(const shared_ptr<const Task::Result> &r)
+void Task::emitResult(const std::shared_ptr<const Task::Result> &r)
 {
-    d->m_processedPercent = 1.0;
-    Q_EMIT progress(progressLabel(), processedSize(), totalSize());
-    Q_EMIT result(r);
+    d->m_progress = d->m_totalProgress;
+    Q_EMIT progress(progressLabel(), currentProgress(), totalProgress(), QPrivateSignal());
+    Q_EMIT result(r, QPrivateSignal());
 }
 
-shared_ptr<Task::Result> Task::makeErrorResult(int errCode, const QString &details)
+std::shared_ptr<Task::Result> Task::makeErrorResult(int errCode, const QString &details)
 {
-    return shared_ptr<Task::Result>(new ErrorResult(errCode, details));
+    return std::shared_ptr<Task::Result>(new ErrorResult(errCode, details));
 }
 
 class Task::Result::Private
