@@ -83,6 +83,7 @@
 #include <cassert>
 
 #include <KSharedConfig>
+#include <KEMailSettings>
 #include <QLocale>
 
 using namespace Kleo;
@@ -223,7 +224,7 @@ static QString get_curve(const QComboBox *cb)
     return cb->currentText();
 }
 
-Q_DECLARE_METATYPE(GpgME::Subkey::PubkeyAlgo);
+Q_DECLARE_METATYPE(GpgME::Subkey::PubkeyAlgo)
 namespace Kleo
 {
 namespace NewCertificateUi
@@ -232,7 +233,7 @@ class WizardPage : public QWizardPage
 {
     Q_OBJECT
 protected:
-    explicit WizardPage(QWidget *parent = Q_NULLPTR)
+    explicit WizardPage(QWidget *parent = nullptr)
         : QWizardPage(parent) {}
 
     NewCertificateWizard *wizard() const
@@ -243,7 +244,7 @@ protected:
 
     QAbstractButton *button(QWizard::WizardButton button) const
     {
-        return QWizardPage::wizard() ? QWizardPage::wizard()->button(button) : 0;
+        return QWizardPage::wizard() ? QWizardPage::wizard()->button(button) : nullptr;
     }
 
     bool isButtonVisible(QWizard::WizardButton button) const
@@ -326,7 +327,7 @@ class AdvancedSettingsDialog : public QDialog
     Q_PROPERTY(bool authenticationAllowed READ authenticationAllowed WRITE setAuthenticationAllowed)
     Q_PROPERTY(QDate expiryDate READ expiryDate WRITE setExpiryDate)
 public:
-    explicit AdvancedSettingsDialog(QWidget *parent = Q_NULLPTR)
+    explicit AdvancedSettingsDialog(QWidget *parent = nullptr)
         : QDialog(parent),
           protocol(UnknownProtocol),
           pgpDefaultAlgorithm(Subkey::AlgoELG_E),
@@ -409,7 +410,7 @@ public:
         QRadioButton *const rb =
             is_rsa(algo) ? ui.rsaRB :
             is_dsa(algo) ? ui.dsaRB :
-            is_ecdsa(algo) ? ui.ecdsaRB : Q_NULLPTR;
+            is_ecdsa(algo) ? ui.ecdsaRB : nullptr;
         if (rb) {
             rb->setChecked(true);
         }
@@ -608,7 +609,7 @@ class ChooseProtocolPage : public WizardPage
 {
     Q_OBJECT
 public:
-    explicit ChooseProtocolPage(QWidget *p = Q_NULLPTR)
+    explicit ChooseProtocolPage(QWidget *p = nullptr)
         : WizardPage(p),
           initialized(false),
           ui()
@@ -666,7 +667,7 @@ class EnterDetailsPage : public WizardPage
 {
     Q_OBJECT
 public:
-    explicit EnterDetailsPage(QWidget *p = Q_NULLPTR)
+    explicit EnterDetailsPage(QWidget *p = nullptr)
         : WizardPage(p), dialog(this), ui()
     {
         ui.setupUi(this);
@@ -729,7 +730,7 @@ class OverviewPage : public WizardPage
 {
     Q_OBJECT
 public:
-    explicit OverviewPage(QWidget *p = Q_NULLPTR)
+    explicit OverviewPage(QWidget *p = nullptr)
         : WizardPage(p), ui()
     {
         ui.setupUi(this);
@@ -761,7 +762,7 @@ class KeyCreationPage : public WizardPage
 {
     Q_OBJECT
 public:
-    explicit KeyCreationPage(QWidget *p = Q_NULLPTR)
+    explicit KeyCreationPage(QWidget *p = nullptr)
         : WizardPage(p),
           ui()
     {
@@ -833,7 +834,7 @@ private Q_SLOTS:
             }
         }
         setField(QStringLiteral("fingerprint"), QString::fromLatin1(result.fingerprint()));
-        job = 0;
+        job = nullptr;
         Q_EMIT completeChanged();
         QMetaObject::invokeMethod(wizard(), "next", Qt::QueuedConnection);
     }
@@ -847,7 +848,7 @@ class ResultPage : public WizardPage
 {
     Q_OBJECT
 public:
-    explicit ResultPage(QWidget *p = Q_NULLPTR)
+    explicit ResultPage(QWidget *p = nullptr)
         : WizardPage(p),
           initialized(false),
           successfullyCreatedSigningCertificate(false),
@@ -918,7 +919,7 @@ public:
 
     bool isError() const
     {
-        return !ui.errorTB->toPlainText().isEmpty();
+        return !ui.errorTB->document()->isEmpty();
     }
 
     bool isComplete() const Q_DECL_OVERRIDE
@@ -992,7 +993,7 @@ private Q_SLOTS:
         // ### better error handling?
         const QString fileName = exportCertificateCommand->openPGPFileName();
         qCDebug(KLEOPATRA_LOG) << "fileName" << fileName;
-        exportCertificateCommand = 0;
+        exportCertificateCommand = nullptr;
         if (fileName.isEmpty()) {
             return;
         }
@@ -1237,7 +1238,7 @@ static const char *oidForAttributeName(const QString &attr)
         if (qstricmp(attrUtf8, oidmap[i].name) == 0) {
             return oidmap[i].oid;
         }
-    return 0;
+    return nullptr;
 }
 
 QDir WizardPage::tmpDir() const
@@ -1384,7 +1385,7 @@ void EnterDetailsPage::updateForm()
 
         int row;
         bool known = true;
-        QValidator *validator = 0;
+        QValidator *validator = nullptr;
         if (attr == QLatin1String("EMAIL")) {
             row = row_index_of(ui.emailLE, ui.gridLayout);
             validator = regex.isEmpty() ? Validation::email() : Validation::email(QRegExp(regex));
@@ -1410,7 +1411,7 @@ void EnterDetailsPage::updateForm()
             row = add_row(ui.gridLayout, &dynamicWidgets);
         }
         if (!validator && !regex.isEmpty()) {
-            validator = new QRegExpValidator(QRegExp(regex), 0);
+            validator = new QRegExpValidator(QRegExp(regex), nullptr);
         }
 
         QLineEdit *le = adjust_row(ui.gridLayout, row, label, preset, validator, readonly, required);
@@ -1436,6 +1437,14 @@ void EnterDetailsPage::updateForm()
     widgets.push_back(ui.addEmailToDnCB);
     widgets.push_back(ui.advancedPB);
 
+    const KEMailSettings e;
+    if (ui.nameLE->text().isEmpty()) {
+        ui.nameLE->setText(e.getSetting(KEMailSettings::RealName));
+    }
+    if (ui.emailLE->text().isEmpty()) {
+        ui.emailLE->setText(e.getSetting(KEMailSettings::EmailAddress));
+    }
+
     set_tab_order(widgets);
 }
 
@@ -1477,7 +1486,7 @@ static bool has_intermediate_input(const QLineEdit *le)
 
 static bool requirementsAreMet(const QVector<Line> &list, QString &error)
 {
-    Q_FOREACH (const Line &line, list) {
+    for (const Line &line : list) {
         const QLineEdit *le = line.edit;
         if (!le) {
             continue;
@@ -1697,7 +1706,7 @@ QString KeyCreationPage::createGnupgKeyParms() const
     } else if (const unsigned int strength = keyStrength()) {
         s << "key-length:    " << strength                 << endl;
     }
-    s     << "key-usage:     " << keyUsages().join(QStringLiteral(" "))    << endl;
+    s     << "key-usage:     " << keyUsages().join(QLatin1Char(' '))    << endl;
     if (const Subkey::PubkeyAlgo subkey = subkeyType()) {
         s << "subkey-type:   " << Subkey::publicKeyAlgorithmAsString(subkey) << endl;
 
@@ -1706,7 +1715,7 @@ QString KeyCreationPage::createGnupgKeyParms() const
         } else if (const unsigned int strength = subkeyStrength()) {
             s << "subkey-length: " << strength             << endl;
         }
-        s << "subkey-usage:  " << subkeyUsages().join(QStringLiteral(" ")) << endl;
+        s << "subkey-usage:  " << subkeyUsages().join(QLatin1Char(' ')) << endl;
     }
     if (pgp() && expiryDate().isValid()) {
         s << "expire-date:   " << expiryDate().toString(Qt::ISODate) << endl;
@@ -1814,7 +1823,7 @@ void AdvancedSettingsDialog::updateWidgetVisibility()
         }
     } else {
         if (ui.tabWidget->indexOf(ui.personalTab) == -1) {
-            ui.tabWidget->addTab(ui.personalTab, tr2i18n("Personal Details", 0));
+            ui.tabWidget->addTab(ui.personalTab, tr2i18n("Personal Details", nullptr));
         }
     }
     ui.uidGB->setVisible(protocol == OpenPGP);
