@@ -92,7 +92,7 @@ public:
             return false;
         }
         const QList<QByteArray> lines = gpgconf.readAll().split('\n');
-        Q_FOREACH (const QByteArray &line, lines)
+        for (const QByteArray &line : lines)
             if (line.startsWith("sysconfdir:"))     //krazy:exclude=strings
                 try {
                     return QDir(QFile::decodeName(hexdecode(line.mid(strlen("sysconfdir:"))))).exists(QStringLiteral("gpgconf.conf"));
@@ -131,7 +131,7 @@ public:
                 i18n("There was an error executing the GnuPG configuration self-check for %2:\n"
                      "  %1\n"
                      "You might want to execute \"gpgconf %3\" on the command line.\n",
-                     message, m_component.isEmpty() ? QStringLiteral("GnuPG") : m_component, arguments().join(QStringLiteral(" ")));
+                     message, m_component.isEmpty() ? QStringLiteral("GnuPG") : m_component, arguments().join(QLatin1Char(' ')));
             if (!output.trimmed().isEmpty()) {
                 m_explaination += QLatin1Char('\n') + i18n("Diagnostics:") + QLatin1Char('\n') + output;
             }
