@@ -129,7 +129,7 @@ struct AssuanContext : AssuanContextBase {
         AssuanContextBase::reset(ctx, &assuan_deinit_server);
     }
 #else
-    void reset(assuan_context_t ctx = 0)
+    void reset(assuan_context_t ctx = nullptr)
     {
         AssuanContextBase::reset(ctx, &my_assuan_release);
     }
@@ -175,7 +175,7 @@ static std::map<std::string, std::string> parse_commandline(const char *line)
     std::map<std::string, std::string> result;
     if (line) {
         const char *begin = line;
-        const char *lastEQ = 0;
+        const char *lastEQ = nullptr;
         while (*line) {
             if (*line == ' ' || *line == '\t') {
                 if (begin != line) {
@@ -214,7 +214,7 @@ static std::map<std::string, std::string> parse_commandline(const char *line)
     return result;
 }
 
-static WId wid_from_string(const QString &winIdStr, bool *ok = 0)
+static WId wid_from_string(const QString &winIdStr, bool *ok = nullptr)
 {
     return static_cast<WId>(winIdStr.toULongLong(ok, 16));
 }
@@ -606,7 +606,7 @@ private:
             return assuan_process_done_msg(conn.ctx.get(), e.error().encodedError(), e.message().c_str());
         } catch (const std::exception &) {
             return assuan_process_done(conn.ctx.get(), gpg_error(GPG_ERR_ASS_SYNTAX));
-        } catch (const gpg_error_t e) {
+        } catch (const gpg_error_t &e) {
             return assuan_process_done(conn.ctx.get(), e);
         } catch (...) {
             return assuan_process_done_msg(conn.ctx.get(), gpg_error(GPG_ERR_UNEXPECTED), "unknown exception caught");
@@ -671,7 +671,7 @@ private:
             return assuan_process_done(conn.ctx.get(), 0);
         } catch (const Exception &e) {
             return assuan_process_done_msg(conn.ctx.get(), e.error().encodedError(), e.message().toUtf8().constData());
-        } catch (const gpg_error_t e) {
+        } catch (const gpg_error_t &e) {
             return assuan_process_done(conn.ctx.get(), e);
         } catch (...) {
             return assuan_process_done_msg(conn.ctx.get(), gpg_error(GPG_ERR_UNEXPECTED), i18n("unknown exception caught").toUtf8().constData());
@@ -790,7 +790,7 @@ private:
 
     static QByteArray dumpStringList(const QStringList &sl)
     {
-        return sl.join(QStringLiteral("\n")).toUtf8();
+        return sl.join(QLatin1Char('\n')).toUtf8();
     }
 
     template <typename T_container>
@@ -926,7 +926,7 @@ AssuanServerConnection::Private::Private(assuan_fd_t fd_, const std::vector< std
     if (const gpg_error_t err = assuan_init_socket_server_ext(&naked_ctx, fd, INIT_SOCKET_FLAGS))
 #else
     {
-        assuan_context_t naked_ctx = 0;
+        assuan_context_t naked_ctx = nullptr;
         if (const gpg_error_t err = assuan_new(&naked_ctx)) {
             throw Exception(err, "assuan_new");
         }
@@ -1100,7 +1100,7 @@ class InquiryHandler : public QObject
 public:
 
 #if defined(HAVE_ASSUAN2) || defined(HAVE_ASSUAN_INQUIRE_EXT)
-    explicit InquiryHandler(const char *keyword_, QObject *p = 0)
+    explicit InquiryHandler(const char *keyword_, QObject *p = nullptr)
         : QObject(p),
 # if !defined(HAVE_ASSUAN2) && !defined(HAVE_NEW_STYLE_ASSUAN_INQUIRE_EXT)
           buffer(0),
@@ -1387,7 +1387,7 @@ void  AssuanCommand::sendData(const QByteArray &data, bool moreToCome)
         throw Exception(err, i18n("Cannot send data"));
     }
     if (!moreToCome)
-        if (const gpg_error_t err = assuan_send_data(d->ctx.get(), 0, 0)) {   // flush
+        if (const gpg_error_t err = assuan_send_data(d->ctx.get(), nullptr, 0)) {   // flush
             throw Exception(err, i18n("Cannot flush data"));
         }
 }
