@@ -49,6 +49,7 @@ QString gpgPath();
 
 QString gpgConfListDir(const char *which);
 QString gpg4winInstallPath();
+QString gpg4winVersion();
 QString gnupgInstallPath();
 const QString& paperKeyInstallPath();
 
@@ -57,6 +58,7 @@ QStringList gnupgFileWhitelist();
 int makeGnuPGError(int code);
 
 bool engineIsVersion(int major, int minor, int patch, GpgME::Engine = GpgME::GpgConfEngine);
+bool haveKeyserverConfigured();
 }
 
 #endif // __KLEOPATRA_GNUPGHELPER_H__
