@@ -62,7 +62,7 @@ namespace
 class TreeView : public QTreeView
 {
 public:
-    explicit TreeView(QWidget *parent = Q_NULLPTR) : QTreeView(parent) {}
+    explicit TreeView(QWidget *parent = nullptr) : QTreeView(parent) {}
 
     QSize minimumSizeHint() const Q_DECL_OVERRIDE
     {
@@ -76,10 +76,10 @@ public:
 KeyTreeView::KeyTreeView(QWidget *parent)
     : QWidget(parent),
       m_proxy(new KeyListSortFilterProxyModel(this)),
-      m_additionalProxy(0),
+      m_additionalProxy(nullptr),
       m_view(new TreeView(this)),
-      m_flatModel(0),
-      m_hierarchicalModel(0),
+      m_flatModel(nullptr),
+      m_hierarchicalModel(nullptr),
       m_stringFilter(),
       m_keyFilter(),
       m_isHierarchical(true)
@@ -88,9 +88,9 @@ KeyTreeView::KeyTreeView(QWidget *parent)
 }
 
 KeyTreeView::KeyTreeView(const KeyTreeView &other)
-    : QWidget(0),
+    : QWidget(nullptr),
       m_proxy(new KeyListSortFilterProxyModel(this)),
-      m_additionalProxy(other.m_additionalProxy ? other.m_additionalProxy->clone() : 0),
+      m_additionalProxy(other.m_additionalProxy ? other.m_additionalProxy->clone() : nullptr),
       m_view(new TreeView(this)),
       m_flatModel(other.m_flatModel),
       m_hierarchicalModel(other.m_hierarchicalModel),
@@ -108,8 +108,8 @@ KeyTreeView::KeyTreeView(const QString &text, const std::shared_ptr<KeyFilter> &
       m_proxy(new KeyListSortFilterProxyModel(this)),
       m_additionalProxy(proxy),
       m_view(new TreeView(this)),
-      m_flatModel(0),
-      m_hierarchicalModel(0),
+      m_flatModel(nullptr),
+      m_hierarchicalModel(nullptr),
       m_stringFilter(text),
       m_keyFilter(kf),
       m_isHierarchical(true)
@@ -212,6 +212,15 @@ void KeyTreeView::init()
                                                      << KeyListModelInterface::TechnicalDetails
                                                      << KeyListModelInterface::ShortKeyID);
     m_view->setModel(rearangingModel);
+
+    std::vector<int> defaultSizes;
+    defaultSizes.push_back(280);
+    defaultSizes.push_back(280);
+    defaultSizes.push_back(100);
+    defaultSizes.push_back(100);
+    defaultSizes.push_back(80);
+    defaultSizes.push_back(80);
+    setColumnSizes(defaultSizes);
 }
 
 KeyTreeView::~KeyTreeView() {}
@@ -276,7 +285,7 @@ void KeyTreeView::setKeyFilter(const std::shared_ptr<KeyFilter> &filter)
 static QItemSelection itemSelectionFromKeys(const std::vector<Key> &keys, const KeyListSortFilterProxyModel &proxy)
 {
     QItemSelection result;
-    Q_FOREACH (const Key &key, keys) {
+    for (const Key &key : keys) {
         const QModelIndex mi = proxy.index(key);
         if (mi.isValid()) {
             result.merge(QItemSelection(mi, mi), QItemSelectionModel::Select);
@@ -340,7 +349,7 @@ void KeyTreeView::setKeys(const std::vector<Key> &keys)
         m_hierarchicalModel->setKeys(sorted);
     }
     if (!sorted.empty())
-        if (QHeaderView *const hv = m_view ? m_view->header() : 0) {
+        if (QHeaderView *const hv = m_view ? m_view->header() : nullptr) {
             hv->resizeSections(QHeaderView::ResizeToContents);
         }
 }
